@@ -5,14 +5,12 @@ use strict;
 use Config;
 use Carp;
 use Config::AutoConf;
-use ExtUtils::LibBuilder;
+use Config::AutoConf::Linker;
 use ExtUtils::ParseXS;
 use ExtUtils::Mkbootstrap;
 use File::Spec::Functions qw.catdir catfile.;
 use File::Path qw.mkpath.;
 
-my $pedantic = $ENV{AMBS_PEDANTIC} || 0;
-
 sub ACTION_pre_install {
     my $self = shift;
 
@@ -23,22 +21,25 @@ sub ACTION_pre_install {
         warn "libjspell.so will install on $usrlib. Be sure to add it to your LIBRARY_PATH\n"
     }
 
+    # Create and prepare for installation the .pc file if not under windows.
     if ($^O ne "MSWin32") {
-        # Create and prepare for installation the .pc file if not under windows.
         _interpolate('jspell.pc.in' => 'jspell.pc',
                      VERSION    => $self->notes('version'),
                      EXECPREFIX => $self->install_destination('bin'),
                      LIBDIR     => $self->install_destination('usrlib'));
         $self->copy_if_modified( from   => "jspell.pc",
-                                 to_dir => catdir('blib','pcfile'),
+                                 to_dir => 'blib/pcfile',
                                  flatten => 1 );
-
-        $self->copy_if_modified( from   => catfile('src','jslib.h'),
-                                 to_dir => catdir('blib','incdir'),
-                                 flatten => 1);
     }
 
-    ## FIXME - usar o Module::Build para isto?
+    # Interpolate the script files, and prepare them for installation
+    _interpolate(catfile('scripts','ujspell.in') => catfile('scripts','ujspell'),
+                 BINDIR => $self->install_destination('bin'));
+    _interpolate(catfile('scripts','jspell-dict.in') => catfile('scripts','jspell-dict'),
+                 LIBDIR => $self->install_destination('usrlib'));
+    _interpolate(catfile('scripts','jspell-installdic.in')=> catfile('scripts','jspell-installdic'),
+                 LIBDIR => $self->install_destination('usrlib'));
+
     for (qw.ujspell jspell-dict jspell-installdic.) {
         $self->copy_if_modified( from   => catfile("scripts",$_),
                                  to_dir => catdir('blib','script'),
@@ -73,15 +74,11 @@ sub ACTION_code {
 
     for my $path (catdir("blib","bindoc"),
                   catdir("blib","pcfile"),
-                  catdir("blib","incdir"),
                   catdir("blib","script"),
                   catdir("blib","bin")) {
         mkpath $path unless -d $path;
     }
 
-    my $libbuilder = ExtUtils::LibBuilder->new;
-    $self->notes(libbuilder => $libbuilder);
-
     my $x = $self->notes('libdir');
     $x =~ s/\\/\\\\/g;
     _interpolate("src/jsconfig.in" => "src/jsconfig.h",
@@ -100,6 +97,59 @@ sub ACTION_code {
     $self->SUPER::ACTION_code;
 }
 
+# sub ACTION_compile_xscode {
+    # my $self = shift;
+    # my $cbuilder = $self->cbuilder;
+
+    # my $archdir = catdir( $self->blib, 'arch', 'auto', 'Lingua', 'Jspell');
+    # mkpath( $archdir, 0, 0777 ) unless -d $archdir;
+
+    # print STDERR "\n** Preparing XS code\n";
+    # my $cfile = catfile("xscode","BibTeX.c");
+    # my $xsfile= catfile("xscode","BibTeX.xs");
+
+    # $self->add_to_cleanup($cfile); ## FIXME
+    # if (!$self->up_to_date($xsfile, $cfile)) {
+    #     ExtUtils::ParseXS::process_file( filename   => $xsfile,
+    #                                      prototypes => 0,
+    #                                      output     => $cfile);
+    # }
+
+    # my $ofile = catfile("xscode","BibTeX.o");
+    # $self->add_to_cleanup($ofile); ## FIXME
+    # if (!$self->up_to_date($cfile, $ofile)) {
+    #     $cbuilder->compile( source               => $cfile,
+    #                         include_dirs         => [ catdir("btparse","src") ],
+    #                         object_file          => $ofile);
+    # }
+
+    # # Create .bs bootstrap file, needed by Dynaloader.
+    # my $bs_file = catfile( $archdir, "BibTeX.bs" );
+    # if ( !$self->up_to_date( $ofile, $bs_file ) ) {
+    #     ExtUtils::Mkbootstrap::Mkbootstrap($bs_file);
+    #     if ( !-f $bs_file ) {
+    #         # Create file in case Mkbootstrap didn't do anything.
+    #         open( my $fh, '>', $bs_file ) or confess "Can't open $bs_file: $!";
+    #     }
+    #     utime( (time) x 2, $bs_file );    # touch
+    # }
+
+    # my $objects = $self->rscan_dir("xscode",qr/\.o$/);
+    # # .o => .(a|bundle)
+    # my $lib_file = catfile( $archdir, "BibTeX.$Config{dlext}" );
+    # if ( !$self->up_to_date( [ @$objects ], $lib_file ) ) {
+    #     my $btparselibdir = $self->install_path('usrlib');
+    #     $cbuilder->link(
+    #                     module_name => 'Text::BibTeX',
+    #                     ($^O !~ /darwin/)?
+    #                     (extra_linker_flags => "-Lbtparse/src -Wl,-R${btparselibdir} -lbtparse "):
+    #                     (extra_linker_flags => "-Lbtparse/src -lbtparse "),
+    #                     objects     => $objects,
+    #                     lib_file    => $lib_file,
+    #                    );
+    # }
+#}
+
 sub ACTION_create_yacc {
     my $self = shift;
 
@@ -129,13 +179,13 @@ sub ACTION_create_manpages {
         `pod2man --section=1 --center="Lingua::Jspell" --release="Lingua-Jspell-$version" $pod $man`;
     }
 
-    my $pod = 'scripts/jspell-dict';
+    my $pod = 'scripts/jspell-dict.in';
     my $man = catfile('blib','bindoc','jspell-dict.1');
     unless ($self->up_to_date($pod, $man)) {
         `pod2man --section=1 --center="Lingua::Jspell" --release="Lingua-Jspell-$version" $pod $man`;
     }
 
-    $pod = 'scripts/jspell-installdic';
+    $pod = 'scripts/jspell-installdic.in';
     $man = catfile('blib','bindoc','jspell-installdic.1');
     unless ($self->up_to_date($pod, $man)) {
         `pod2man --section=1 --center="Lingua::Jspell" --release="Lingua-Jspell-$version" $pod $man`;
@@ -147,10 +197,6 @@ sub ACTION_create_objects {
     my $cbuilder = $self->cbuilder;
 
     my $c_files = $self->rscan_dir('src', qr/\.c$/);
-
-    my $extra_compiler_flags = $self->notes('ccurses');
-    $extra_compiler_flags = "-Wall -Werror $extra_compiler_flags" if $pedantic;
-
     for my $file (@$c_files) {
         my $object = $file;
         $object =~ s/\.c/.o/;
@@ -158,7 +204,7 @@ sub ACTION_create_objects {
         $cbuilder->compile(object_file  => $object,
                            source       => $file,
                            include_dirs => ["src"],
-                           extra_compiler_flags => $extra_compiler_flags);
+                           extra_compiler_flags => $self->notes('ccurses'));
     }
 }
 
@@ -167,32 +213,40 @@ sub ACTION_create_binaries {
     my $self = shift;
     my $cbuilder = $self->cbuilder;
 
-    my $libbuilder = $self->notes('libbuilder');
-    my $EXEEXT = $libbuilder->{exeext};
+    my $EXEEXT = $Config::AutoConf::EXEEXT;
+
+    my ($LD,$CCL) = Config::AutoConf::Linker::detect_library_link_commands($cbuilder);
+    die "Can't get a suitable way to compile a C library\n" if (!$LD || !$CCL);
+
     my $extralinkerflags = $self->notes('lcurses').$self->notes('ccurses');
 
     my @toinstall;
-    my $exe_file = catfile("src" => "jspell$EXEEXT");
-    $self->config_data("jspell" => catfile($self->config_data("bindir") => "jspell$EXEEXT"));
+    my $exe_file = catfile("src","jspell$EXEEXT");
     push @toinstall, $exe_file;
-    my $object   = catfile("src" => "jmain.o");
+    my $object   = catfile("src","jmain.o");
     my $libdir   = $self->install_path('usrlib');
     if (!$self->up_to_date($object, $exe_file)) {
-        $libbuilder->link_executable(exe_file => $exe_file,
-                                     objects  => [ $object ],
-                                     extra_linker_flags => "-Lsrc -ljspell $extralinkerflags");
+        $CCL->($cbuilder,
+               exe_file => $exe_file,
+               objects  => [ $object ],
+               ($^O !~ /darwin/)?
+               (extra_linker_flags => "-Lsrc -Wl,-R${libdir} -ljspell $extralinkerflags"):
+               (extra_linker_flags => "-Lsrc -ljspell $extralinkerflags"));
     }
 
     $exe_file = catfile("src","jbuild$EXEEXT");
-    $self->config_data("jbuild" => catfile($self->config_data("bindir") => "jbuild$EXEEXT"));
     push @toinstall, $exe_file;
     $object   = catfile("src","jbuild.o");
     if (!$self->up_to_date($object, $exe_file)) {
-        $libbuilder->link_executable(exe_file => $exe_file,
-                                     objects  => [ $object ],
-                                     extra_linker_flags => "-Lsrc -ljspell $extralinkerflags");
+        $CCL->($cbuilder,
+               exe_file => $exe_file,
+               objects  => [ $object ],
+               ($^O !~ /darwin/)?
+               (extra_linker_flags => "-Lsrc -Wl,-R${libdir} -ljspell $extralinkerflags"):
+               (extra_linker_flags => "-Lsrc -ljspell $extralinkerflags"));
     }
 
+
     for my $file (@toinstall) {
         $self->copy_if_modified( from    => $file,
                                  to_dir  => "blib/bin",
@@ -204,8 +258,7 @@ sub ACTION_create_library {
     my $self = shift;
     my $cbuilder = $self->cbuilder;
 
-    my $libbuilder = $self->notes('libbuilder');
-    my $LIBEXT = $libbuilder->{libext};
+    my $LIBEXT = $Config::AutoConf::LIBEXT;
 
     my @files = qw!correct defmt dump gclass good hash jjflags
                    jslib jspell lookup makedent sc-corr term
@@ -213,6 +266,9 @@ sub ACTION_create_library {
 
     my @objects = map { catfile("src","$_.o") } @files;
 
+    my ($LD,$CCL) = Config::AutoConf::Linker::detect_library_link_commands($cbuilder);
+    die "Can't get a suitable way to compile a C library\n" if (!$LD || !$CCL);
+
     my $libpath = $self->notes('libdir');
     $libpath = catfile($libpath, "libjspell$LIBEXT");
     my $libfile = catfile("src","libjspell$LIBEXT");
@@ -221,11 +277,12 @@ sub ACTION_create_library {
     $extralinkerflags.=" -install_name $libpath" if $^O =~ /darwin/;
 
     if (!$self->up_to_date(\@objects, $libfile)) {
-        $libbuilder->link(module_name => 'libjspell',
-                          extra_linker_flags => $extralinkerflags,
-                          objects => \@objects,
-                          lib_file => $libfile,
-                         );
+        $LD->($cbuilder,
+              module_name => 'libjspell',
+              extra_linker_flags => $extralinkerflags,
+              objects => \@objects,
+              lib_file => $libfile,
+             );
     }
 
     my $libdir = catdir($self->blib, 'usrlib');
